@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: free
 version: 4.12.4
-id: free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
-key: free_LYcwEkhQpGv1niHnHVui2r
+id: free-4.12.4-4d7b26d357ab46561e822913cd7a6493
+key: free_H3gabvSicISAtCHFi28Y0v
 license: BSD3
 copyright: Copyright (C) 2008-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -45,18 +45,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
-hs-libraries: HSfree-4.12.4-LYcwEkhQpGv1niHnHVui2r
+hs-libraries: HSfree-4.12.4-H3gabvSicISAtCHFi28Y0v
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
+    bifunctors-5.3-b98299755d5303d55588251f793bb639
     comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
-    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
-    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    profunctors-5.2-a3b810f661c38ea494793460d496159b
+    semigroupoids-5.0.1-53b0b3ecfca9d658a051ef7b22e11130
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
